import setuptools
setuptools.setup(
name='ravinathvizua',
version='0.1',
author="Ravinath Wanni Arachchi",
author_email="ravinathwanni@gmail.com",
description="key for the company's project",
packages=setuptools.find_packages(),
classifiers=[
"Programming Language :: Python :: 3",
"License :: OSI Approved :: MIT License",
"Operating System :: OS Independent",
],
)